@@ -70,6 +70,18 @@ class AptPackagesManifest(ManifestInterface):
         )
 
 
+class ApkPackagesManifest(ManifestInterface):
+    @staticmethod
+    def markdown_piece(container) -> str:
+        return "\n".join(
+            [
+                "## Apk Packages",
+                "",
+                quoted_output(container, "apk list --installed"),
+            ]
+        )
+
+
 class CondaEnvironmentManifest(ManifestInterface):
     @staticmethod
     def markdown_piece(container) -> str:
